<template>
    <div>
        <el-row type="flex" class="rowStyle">
            <el-col :xs="5" :sm="3">
                <el-avatar
                    :size="50"
                    src=""
                    class="cursor--pointer"
                ></el-avatar>
                <!-- <div class="satisfaction">
                    <i class="icon-star pam-icon icon--yellow satisfaction"></i>
                    <span>{{'1'}}</span>
                </div> -->
            </el-col>
            <el-col :xs="14" :sm="15">
                <div class="smTxt_bold name">{{client.name}}</div>
                <div class="message">預約成功</div>
                <div class="professionals">
                    <template v-if="client.requirement">
                        <span
                            v-for="(item, index) in requirements"
                            :key="index"
                            class="professionalsTxt"
                        >#{{item}}</span>
                    </template>
                    <template v-else>
                        <span class="professionalsTxt noProfessionalsTxt"
                        >(客戶未提供需求項目)</span>
                    </template>
                </div>
            </el-col>
            <el-col class="flex-column contactInfo" :xs="5" :sm="6">
                <div class="smTxt_bold cursor--pointer"
                    :class="client.communicateStatus"
                    @click="openDetail"
                >{{isReserved ? '已預約' : '已聯絡'}}
                </div>
                <div class="date xsTxt text--mid_grey">{{date}}</div>
                <div class="xsTxt text--mid_grey">{{time}}</div>
            </el-col>
        </el-row>

        <Ui-Dialog
            :isVisible.sync="isVisibleDialog"
            :width="width"
        >
            <h5 class="subTitle text--center mb-30"
            >{{isReserved ? '預約成功' : '已聯絡資訊'}}</h5>
            <p class="smTxt text-right">{{client.appointmentDate | formatDate}}</p>
            <div class="dialogTxt">
                <p>姓名：{{client.name}}</p>
                <p>電話：{{client.phone}}</p>
                <p>Email：{{client.email}}</p>
                <p>性別：{{client.gender === 'male' ? '男性' : '女性'}}</p>
                <p>年齡：{{client.age}}</p>
                <p>職業：{{client.job}}</p>
                <p>需求：{{client.requirements}}</p>
                <p>連絡時段一：{{hopeContactTime}}</p>
                <div class="mt-30 text--center" v-if="isReserved">
                    <el-button>標註為已連絡</el-button>
                </div>
            </div>
        </Ui-Dialog>
    </div>
</template>

<script lang="ts">
import { Vue, Component, Prop } from 'nuxt-property-decorator';
import { ClientInfo } from '~/assets/ts/api/consultant';
import { isMobileDevice } from '~/assets/ts/device';

@Component
export default class ClientList extends Vue {
    @Prop() client!: ClientInfo;
    isVisibleDialog = false;
    width = '';

    get requirements() {
        return this.client.requirement.split(',');
    }

    get hopeContactTime() {
        return this.client.hopeContactTime.slice(1, this.client.hopeContactTime.length - 1)
    }
    get time() {
        if (this.client.appointmentDate) {
            const newDate = new Date(this.client.appointmentDate);
            const hours = newDate.getHours();
            const minutes = newDate.getMinutes();
            return `${hours} : ${minutes}`
        }
        return ''
    }

    get date() {
        if (this.client.appointmentDate) {
            const newDate = new Date(this.client.appointmentDate);
            const month = newDate.getMonth();
            const date = newDate.getDate();
            return `${month} / ${date}`
        }
        return ''
    }

    get isReserved() {
        return this.client.communicateStatus === 'reserved';
    }

    openDetail() {
        this.width = isMobileDevice() ? '80%' : '';
        this.isVisibleDialog = true;
    }

}
</script>

<style lang="scss" scoped>
    .rowStyle {
        padding: 10px;
        background-color: $PRIMARY_WHITE;
        margin-bottom: 10px;
        display: flex;
        justify-content: space-between;

        .satisfaction {
            font-size: 12px;
            font-weight: bold;
            margin-top: 5px;
        }

        .message {
            margin:10px 0;
        }

        .professionals {
            overflow: hidden;
            white-space: nowrap;
            text-overflow: ellipsis;

            .professionalsTxt {
                font-size: 12px;
                font-weight: bold;
                margin-right: 5px;
            }

            .noProfessionalsTxt {
                color: $PRUDENTIAL_GREY;
                font-weight: lighter;
            }
        }

        .contactInfo {
            text-align: right;
            .date {
                font-size: 12px;
            }
        }

        .reserved {
            @extend .text--primary;
        }

        .contacted {
            color: $SKY_BLUE;
        }
    }

    .flex-column {
        display: flex;
        flex-direction: column;
        justify-content: space-between;
    }

    .dialogTxt {
        font-size: 20px;
    }

    .text-right {
        text-align: right;
    }
</style>